# Release Notes for STM32G4xx CMSIS

Copyright © 2019 STMicroelectronics

# License

This software component is licensed by ST under Apache 2.0 license, the “License”; You may not use this component except in compliance with the License. You may obtain a copy of the License at:

https://opensource.org/licenses/Apache-2.0

# Purpose

This driver provides the CMSIS device for the stm32g4xx products. This covers following series :

- STM32G431/41xx

- STM32G471xx

- STM32G473/83xx

- STM32G474/84xx

This driver is composed of the descriptions of the registers under “Include” directory.

Various template file are provided to easily build an application. They can be adapted to fit applications requirements.

- Templates/system_stm32g4xx.c contains the initialization code referred as SystemInit.
- Startup files are provided as example for IAR©, KEIL© and SW4STM32©.
- Linker files are provided as example for IAR©, KEIL© and SW4STM32©.

# Update History

V1.0.0 / 12-April-2019

## Main Changes

### First release

First official release for STM32G4xx devices

## Contents

CMSIS devices files for STM32G431xx, STM32G441xx, STM32G471xx, STM32G473xx, STM32G474xx and STM32G484xx.

## Known Limitations

Headline
Support of STM32G483xx device in CMSIS

## Development Toolchains and Compilers

- IAR Embedded Workbench for ARM (EWARM) toolchain V8.20.2
- RealView Microcontroller Development Kit (MDK-ARM) toolchain V5.25
- System Workbench STM32 (SW4STM32) toolchain V2.7.2

## Supported Devices and boards

- STM32G431xx, STM32G441xx devices
- STM32G471xx devices
- STM32G473xx devices
- STM32G474xx, STM32G484xx devices